@@ -3,9 +3,7 @@
 import logging
 import re
 from hashlib import md5
-
-import six
-from six.moves import urllib
+import urllib.parse
 
 import cherrypy
 from cherrypy._cpcompat import text_or_bytes
@@ -211,8 +209,8 @@ def proxy(base=None, local='X-Forwarded-Host', remote='X-Forwarded-For',
             cherrypy.log('Testing remote %r:%r' % (remote, xff), 'TOOLS.PROXY')
         if xff:
             if remote == 'X-Forwarded-For':
-                # Bug #1268
-                xff = xff.split(',')[0].strip()
+                # Grab the first IP in a comma-separated list. Ref #1268.
+                xff = next(ip.strip() for ip in xff.split(','))
             request.remote.ip = xff
 
 
@@ -307,7 +305,7 @@ class SessionAuth(object):
 
     def login_screen(self, from_page='..', username='', error_msg='',
                      **kwargs):
-        return (six.text_type("""<html><body>
+        return (str("""<html><body>
 Message: %(error_msg)s
 <form method="post" action="do_login">
     Login: <input type="text" name="username" value="%(username)s" size="10" />
@@ -406,23 +404,22 @@ Message: %(error_msg)s
 
 
 def session_auth(**kwargs):
+    """Session authentication hook.
+
+    Any attribute of the SessionAuth class may be overridden
+    via a keyword arg to this function:
+
+    """ + '\n    '.join(
+        '{!s}: {!s}'.format(k, type(getattr(SessionAuth, k)).__name__)
+        for k in dir(SessionAuth)
+        if not k.startswith('__')
+    )
     sa = SessionAuth()
     for k, v in kwargs.items():
         setattr(sa, k, v)
     return sa.run()
 
 
-session_auth.__doc__ = (
-    """Session authentication hook.
-
-    Any attribute of the SessionAuth class may be overridden via a keyword arg
-    to this function:
-
-    """ + '\n'.join(['%s: %s' % (k, type(getattr(SessionAuth, k)).__name__)
-                     for k in dir(SessionAuth) if not k.startswith('__')])
-)
-
-
 def log_traceback(severity=logging.ERROR, debug=False):
     """Write the last error's traceback to the cherrypy error log."""
     cherrypy.log('', 'HTTP', severity=severity, traceback=True)
@@ -589,20 +586,13 @@ def accept(media=None, debug=False):
 
 class MonitoredHeaderMap(_httputil.HeaderMap):
 
+    def transform_key(self, key):
+        self.accessed_headers.add(key)
+        return super(MonitoredHeaderMap, self).transform_key(key)
+
     def __init__(self):
         self.accessed_headers = set()
-
-    def __getitem__(self, key):
-        self.accessed_headers.add(key)
-        return _httputil.HeaderMap.__getitem__(self, key)
-
-    def __contains__(self, key):
-        self.accessed_headers.add(key)
-        return _httputil.HeaderMap.__contains__(self, key)
-
-    def get(self, key, default=None):
-        self.accessed_headers.add(key)
-        return _httputil.HeaderMap.get(self, key, default=default)
+        super(MonitoredHeaderMap, self).__init__()
 
 
 def autovary(ignore=None, debug=False):
